EasyDropdownComponent class

Inheritance

Constructors

EasyDropdownComponent({Key? key, required List<EasyDropdownItem> items, String title = '', String description = '', String? leadingIcon, String? searchHintText, bool enableSearch = false, bool isSimplified = false, double? maxHeight, double? maxWidth, double? listHeight, double? listWidth, double fieldWidth = 200, double fieldHeight = 40, dynamic onSelectionChanged(EasyDropdownItem)?, dynamic onClose(List<EasyDropdownItem>)?, dynamic onListChanged(List<EasyDropdownItem>)?, Widget? customField, Widget? customSearchField, TextEditingController? searchController, Widget? customClearButton, Widget? customSelectAllButton, Widget customListItem(EasyDropdownItem item, VoidCallback onTap)?, Widget customSelectedListItem(EasyDropdownItem item, VoidCallback onTap)?, Widget? customSelectedHeader, Widget? customAvailableHeader, Widget? customEmptyResultsWidget, BoxDecoration? dropdownDecoration, double dropdownElevation = 8, EdgeInsetsGeometry? dropdownPadding, EdgeInsetsGeometry dropdownOuterPadding = const EdgeInsets.only(top: 4), bool searchMatcher(EasyDropdownItem item, String searchText)?})
const

Properties

customAvailableHeader Widget?
final
customClearButton Widget?
final
customEmptyResultsWidget Widget?
final
customField Widget?
final
customListItem Widget Function(EasyDropdownItem item, VoidCallback onTap)?
final
customSearchField Widget?
final
customSelectAllButton Widget?
final
customSelectedHeader Widget?
final
customSelectedListItem Widget Function(EasyDropdownItem item, VoidCallback onTap)?
final
description String
final
final
final
final
final
enableSearch bool
final
fieldHeight double
final
fieldWidth double
final
hashCode int
The hash code for this object.
no setterinherited
isSimplified bool
final
items List<EasyDropdownItem>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingIcon String?
final
listHeight double?
final
listWidth double?
final
maxHeight double?
final
maxWidth double?
final
onClose → dynamic Function(List<EasyDropdownItem>)?
final
onListChanged → dynamic Function(List<EasyDropdownItem>)?
final
onSelectionChanged → dynamic Function(EasyDropdownItem)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchController TextEditingController?
final
searchHintText String?
final
searchMatcher bool Function(EasyDropdownItem item, String searchText)?
final
title String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<EasyDropdownComponent>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited