EasyDropdownItem class
Constructors
- EasyDropdownItem({required String id, required Widget widget, bool selected = false, String? searchableText})
-
const
Properties
Methods
-
copyWith(
{String? id, Widget? widget, bool? selected, String? searchableText}) → EasyDropdownItem -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override