EasyDropdownStyle class

Constructors

EasyDropdownStyle({Color? backgroundColor, Color? borderColor, Color? textColor, Color? selectedItemColor, Color? unselectedItemColor, Color? searchBarColor, Color? dividerColor})
const

Properties

backgroundColor Color?
final
borderColor Color?
final
dividerColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchBarColor Color?
final
selectedItemColor Color?
final
textColor Color?
final
unselectedItemColor Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited